/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.security.trans.task.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.security.trans.task.dto.TaskDTO;
import org.security.trans.task.dto.TaskHandinDTO;
import org.security.trans.task.vo.TaskTodoVO;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.security.trans.task.entity.TaskHandin;
import org.security.trans.task.vo.TaskHandinVO;
import org.security.trans.task.service.ITaskHandinService;
import org.springblade.core.boot.ctrl.BladeController;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.List;

/**
 * 任务-任务提报 控制器
 *
 * @author BladeX
 * @since 2022-03-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("/taskhandin")
@Api(value = "任务-任务提报", tags = "任务-任务提报接口")
public class TaskHandinController extends BladeController {

	private final ITaskHandinService taskHandinService;

	/**
	 * 详情
	 */
	@GetMapping("/{id}")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入id")
	public R<TaskHandinVO> detail(@PathVariable BigDecimal id) {
		TaskHandinVO detail = taskHandinService.getDetail(id);
		return R.data(detail);
	}

	/**
	 * 自定义分页 任务-任务提报
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入taskHandin")
	public R<IPage<TaskHandinVO>> list(TaskHandinDTO taskHandinDTO, Query query) {
		IPage<TaskHandinVO> pages = taskHandinService.selectTaskHandinPage(Condition.getPage(query), taskHandinDTO);
		return R.data(pages);
	}

	/**
	 * 暂存 任务-任务提报
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "暂存", notes = "传入taskHandin")
	public R save(@Valid @RequestBody TaskHandinDTO taskHandin){
		return taskHandinService.saveTaskHandin(taskHandin).isSuccess() ? R.success("操作成功") : R.fail("操作失败");
	}

	/**
	 * 修改 任务-任务提报
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入taskHandin")
	public R update(@Valid @RequestBody TaskHandin taskHandin) {
		return R.status(taskHandinService.updateTaskHandin(taskHandin));
	}

	/**
	 * 新增或修改 任务-任务提报
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入taskHandin")
	public R submit(@Valid @RequestBody TaskHandinDTO taskHandin) {
		return taskHandinService.saveTaskHandin(taskHandin);
	}


	/**
	 * 提报 任务-任务提报
	 */
	@PostMapping("/handin")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "提报", notes = "传入taskHandin")
	public R handin(@Valid @RequestBody TaskHandinDTO taskHandin) throws ParseException{
		return taskHandinService.handin(taskHandin);
	}


	/**
	 * 删除 任务-任务提报
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(taskHandinService.removeByIds(Func.toLongList(ids)));
	}



	/**
	 * 发布 任务-任务下发
	 *
	 */
	@PostMapping("/publish")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "发布", notes = "传入task")
	public R submit(@Valid @RequestBody TaskDTO task) {
		return taskHandinService.publishTask(task);
	}

	/**
	 * 查询待办
	 */
	@GetMapping("/todolist")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "列表", notes = "")
	public R<List<TaskTodoVO>> todoList() {
		List<TaskTodoVO> pages = taskHandinService.selectTaskTodo();
		return R.data(pages);
	}


	/**
	 * 终止任务
	 */
	@PostMapping("/endTask")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R endTask(@Valid @RequestBody TaskDTO task) {
		return taskHandinService.endTaskByIds(task);
	}

}
